#[non_exhaustive]pub enum Layout {
Circular,
Hierarchical(Orientation),
ForceDirected,
Bipartite(Option<HashSet<NodeIndex>>),
Random,
}Expand description
Different layout algorithms for graph visualization.
The layout algorithms can also be called directly from their respective submodules of the
layout module.
For examples, see the examples directory.
This enum is marked as non-exhaustive to allow for adding more layout algorithms without necessitating a breaking change.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Circular
Nodes are arranged in a circular layout.
See circular_layout for more details or
calling the layout function directly.
Hierarchical(Orientation)
Nodes are arranged in a hierarchical layout.
See hierarchical_layout for more
details or calling the layout function directly.
ForceDirected
Nodes are arranged using a force-directed layout.
See force_directed_layout for
more details or calling the layout function directly.
Bipartite(Option<HashSet<NodeIndex>>)
Nodes are arranged in a bipartite layout.
The provided HashSet contains the node IDs for the left partition. If None is
provided, the layout function will attempt to determine the bipartition using a
breadth-first traversal.
Random
Nodes are arranged randomly.
See random_layout for more details or calling the
layout function directly.